==> haskell-these-1.2.1-227-loong64.pkg.tar.zst: usr/share/haskell/register/haskell-these.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 these
version:              1.2.1
visibility:           public
id:                   these-1.2.1-FFxH0GxUZUDAtgQSChMM1W
key:                  these-1.2.1-FFxH0GxUZUDAtgQSChMM1W
license:              BSD-3-Clause
maintainer:           Oleg Grenrus <oleg.grenrus@iki.fi>
author:               C. McCann, Oleg Grenrus
homepage:             https://github.com/haskellari/these
synopsis:             An either-or-both data type.
description:
    This package provides a data type @These a b@ which can hold a value of either
    type or values of each type. This is usually thought of as an "inclusive or"
    type (contrasting @Either a b@ as "exclusive or") or as an "outer join" type
    (contrasting @(a, b)@ as "inner join").

    @
    data These a b = This a | That b | These a b
    @

    Since version 1, this package was split into parts:

    * <https://hackage.haskell.org/package/semialign semialign> For @Align@ and @Zip@ type-classes.

    * <https://hackage.haskell.org/package/semialign-indexed semialign-indexed> For @SemialignWithIndex@ class, providing @ialignWith@ and @izipWith@.

    * <https://hackage.haskell.org/package/these-lens these-lens> For lens combinators.

    * <http://hackage.haskell.org/package/monad-chronicle monad-chronicle> For transformers variant of @These@.

category:             Data, These
abi:                  fe63ede6321d16e69a056c9e7253faf8
exposed:              True
exposed-modules:      Data.Functor.These Data.These Data.These.Combinators
import-dirs:          /usr/lib/ghc-9.6.6/site-local/these-1.2.1
library-dirs:         /usr/lib/ghc-9.6.6/site-local/these-1.2.1
library-dirs-static:  /usr/lib/ghc-9.6.6/site-local/these-1.2.1
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-these
hs-libraries:         HSthese-1.2.1-FFxH0GxUZUDAtgQSChMM1W
depends:
    assoc-1.1.1-CXSd7PfWtZ44ssseqrHtHW base-4.18.2.1 binary-0.8.9.1
    deepseq-1.4.8.1 hashable-1.4.7.0-1GSULm1uRgQBgX6mu6tvYD

haddock-interfaces:   /usr/share/doc/haskell-these/html/these.haddock
haddock-html:         /usr/share/doc/haskell-these/html
' | '/usr/bin/ghc-pkg-9.6.6' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-these-1.2.1-230-loong64.pkg.tar.zst: usr/share/haskell/register/haskell-these.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 these
version:              1.2.1
visibility:           public
id:                   these-1.2.1-7cZGVd7UTfy2HKT7yUNRZL
key:                  these-1.2.1-7cZGVd7UTfy2HKT7yUNRZL
license:              BSD-3-Clause
maintainer:           Oleg Grenrus <oleg.grenrus@iki.fi>
author:               C. McCann, Oleg Grenrus
homepage:             https://github.com/haskellari/these
synopsis:             An either-or-both data type.
description:
    This package provides a data type @These a b@ which can hold a value of either
    type or values of each type. This is usually thought of as an "inclusive or"
    type (contrasting @Either a b@ as "exclusive or") or as an "outer join" type
    (contrasting @(a, b)@ as "inner join").

    @
    data These a b = This a | That b | These a b
    @

    Since version 1, this package was split into parts:

    * <https://hackage.haskell.org/package/semialign semialign> For @Align@ and @Zip@ type-classes.

    * <https://hackage.haskell.org/package/semialign-indexed semialign-indexed> For @SemialignWithIndex@ class, providing @ialignWith@ and @izipWith@.

    * <https://hackage.haskell.org/package/these-lens these-lens> For lens combinators.

    * <http://hackage.haskell.org/package/monad-chronicle monad-chronicle> For transformers variant of @These@.

category:             Data, These
abi:                  acb514873b6adffb4eac6d578a00326d
exposed:              True
exposed-modules:      Data.Functor.These Data.These Data.These.Combinators
import-dirs:          /usr/lib/ghc-9.6.6/site-local/these-1.2.1
library-dirs:         /usr/lib/ghc-9.6.6/site-local/these-1.2.1
library-dirs-static:  /usr/lib/ghc-9.6.6/site-local/these-1.2.1
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-these
hs-libraries:         HSthese-1.2.1-7cZGVd7UTfy2HKT7yUNRZL
depends:
    assoc-1.1.1-CXSd7PfWtZ44ssseqrHtHW base-4.18.2.1 binary-0.8.9.1
    deepseq-1.4.8.1 hashable-1.4.7.0-LSmBhr9Bt59DsIlhOBFmCL

haddock-interfaces:   /usr/share/doc/haskell-these/html/these.haddock
haddock-html:         /usr/share/doc/haskell-these/html
' | '/usr/bin/ghc-pkg-9.6.6' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
